Giocci (giocci v0.3.1)
Copy MarkdownClient API for Giocci.
Summary
Functions
Execute a function on an engine via the relay.
Execute a function asynchronously and send the result to server.
Register this client to a relay.
Save a module to the relay.
Functions
Execute a function on an engine via the relay.
Options:
:timeout- Client call timeout in milliseconds.:measure_to- When set to a pid, sends measurement timestamps as{:giocci_measurements, timestamps}to that process.
@spec exec_func_async(String.t(), tuple(), GenServer.server(), keyword()) :: :ok | {:error, reason :: term()}
Execute a function asynchronously and send the result to server.
The result is delivered to server as {:giocci, result}.
Options:
:timeout- Client call timeout in milliseconds.:measure_to- When set to a pid, sends measurement timestamps as{:giocci_measurements, timestamps}to that process.
Register this client to a relay.
Options:
:timeout- Client call timeout in milliseconds.:measure_to- When set to a pid, sends measurement timestamps as{:giocci_measurements, timestamps}to that process.
Save a module to the relay.
Options:
:timeout- Client call timeout in milliseconds.:measure_to- When set to a pid, sends measurement timestamps as{:giocci_measurements, timestamps}to that process.